# Lingua


Lingua-py is an Python wrapper for the [Rust][1] [lingua][2] crate with [PyO3/Maturin][3].

## Summary

Lingua is a NIF-based bridge for the [lingua][2] [Rust][1] language detection library.

## Usage 

Empty. I'll write here in the future.


# License

[Apache License v2](./LICENSE), and lingua-rs is also [Apache License v2](https://github.com/pemistahl/lingua-rs/blob/master/LICENSE).






[1]: https://www.rust-lang.org 
[2]: https://crates.io/crates/lingua
[3]: https://www.maturin.rs/